@@ -1,4 +1,4 @@
-__version__ = "0.5.16"
+__version__ = "0.5.17"
 
 from .core import (
     magicclass,
@@ -22,6 +22,6 @@ from .fields import field, vfield
 from .gui._base import wraps, defaults, MagicTemplate, PopUpMode
 from ._typing import WidgetType
 from .gui.keybinding import Key
-from . import widgets, utils, ext
+from . import widgets, utils
 
 from magicgui import *
\ No newline at end of file
