@@ -1,6 +1,16 @@
 from __future__ import annotations
 from functools import wraps as functools_wraps
-from typing import Any, Callable, TYPE_CHECKING, Iterable, Iterator, TypeVar, overload, MutableSequence
+from typing import (
+    Any,
+    Callable,
+    TYPE_CHECKING,
+    Generic,
+    Iterable,
+    Iterator,
+    TypeVar,
+    overload,
+    MutableSequence
+    )
 from typing_extensions import _AnnotatedAlias
 import inspect
 import warnings
@@ -13,14 +23,29 @@ from qtpy.QtGui import QIcon
 
 from magicgui.events import Signal
 from magicgui.signature import MagicParameter
-from magicgui.widgets import FunctionGui, FileEdit, EmptyWidget, Widget, Container, Image, Table, Label
+from magicgui.widgets import (
+    FunctionGui,
+    FileEdit,
+    EmptyWidget,
+    Widget,
+    Container,
+    Image,
+    Table,
+    Label
+    )
 from magicgui.application import use_app
 from magicgui.widgets._bases.widget import Widget
 from magicgui.widgets._bases import ButtonWidget, ValueWidget
 from macrokit import Expr, Head, Symbol, symbol
 
 from .keybinding import as_shortcut
-from .mgui_ext import AbstractAction, Action, FunctionGuiPlus, PushButtonPlus, _LabeledWidgetAction, mguiLike
+from .mgui_ext import (
+    AbstractAction,
+    Action,
+    FunctionGuiPlus,
+    PushButtonPlus,
+    _LabeledWidgetAction,
+    mguiLike)
 from .utils import get_parameters, define_callback
 from ._macro import GuiMacro
 
@@ -122,7 +147,7 @@ class MagicTemplate:
     
     __init_subclass__ = check_override
     
-    def show(self) -> None:
+    def show(self, run: bool) -> None:
         raise NotImplementedError()
     
     def hide(self) -> None:
@@ -277,7 +302,7 @@ class MagicTemplate:
         RuntimeError
             If ``child_clsname`` was not found in child widget list. This error will NEVER be raised
             in the user's side.
-        """        
+        """
         for child_instance in self._iter_child_magicclasses():
             if child_instance.__class__.__name__ == child_clsname:
                 # get the position of predefined child widget
@@ -983,9 +1008,11 @@ def _field_as_getter(self, bound_value: MagicField):
         return bound_value.as_getter(ins)(w)
     return _func
 
+
 def _need_record(func: Callable):
     return get_additional_option(func, "record", True)
 
+
 def value_widget_callback(gui: MagicTemplate,
                           widget: ValueWidget, 
                           name: str, 
@@ -1023,6 +1050,7 @@ def value_widget_callback(gui: MagicTemplate,
         return None
     return _set_value
 
+
 def nested_function_gui_callback(gui: MagicTemplate, fgui: FunctionGui):
     """
     Define a FunctionGui callback, including macro recording.
