@@ -1,8 +1,7 @@
 from __future__ import annotations
 from inspect import signature
-from typing import Any, Callable
+from typing import Any, Callable, TypeVar
 import warnings
-from PyQt5.QtWidgets import QVBoxLayout
 from qtpy.QtWidgets import QMenuBar, QWidget, QMainWindow, QBoxLayout
 from qtpy.QtCore import Qt
 from magicgui.widgets import Container, MainWindow,Label, FunctionGui, Image, Table
@@ -128,7 +127,7 @@ class ClassGuiBase(BaseGui):
                 
                 if isinstance(widget, MenuGui):
                     # Add menubar to container
-                    widget.__magicclass_parent__ = self
+                    # widget.__magicclass_parent__ = self
                     if self._menubar is None:
                         # if widget has no menubar, a new one should be created.
                         self._menubar = QMenuBar(parent=self.native)
@@ -136,7 +135,10 @@ class ClassGuiBase(BaseGui):
                             self.native: QMainWindow
                             self.native.setMenuBar(self._menubar)
                         else:
-                            _layout: QBoxLayout = self.native.layout()
+                            if hasattr(self._widget, "_scroll_area"):
+                                _layout: QBoxLayout = self._widget._qwidget.layout()
+                            else:
+                                _layout = self.native.layout()
                             if _layout.menuBar() is None:
                                 _layout.setMenuBar(self._menubar)
                             else:
@@ -152,7 +154,7 @@ class ClassGuiBase(BaseGui):
                 
                 elif isinstance(widget, ContextMenuGui):
                     # Add context menu to container
-                    widget.__magicclass_parent__ = self
+                    # widget.__magicclass_parent__ = self
                     self.native.setContextMenuPolicy(Qt.CustomContextMenu)
                     self.native.customContextMenuRequested.connect(
                         define_context_menu(widget, self.native)
@@ -160,13 +162,16 @@ class ClassGuiBase(BaseGui):
                     _hist.append((name, type(attr), "ContextMenuGui"))
                 
                 elif isinstance(widget, ToolBarGui):
-                    widget.__magicclass_parent__ = self
+                    # widget.__magicclass_parent__ = self
                     if issubclass(self.__class__, MainWindow):
                         self.native: QMainWindow
                         self.native.addToolBar(widget.native)
                     else:
                         # self is not a main window object
-                        _layout: QBoxLayout = self._widget._layout
+                        if hasattr(self._widget, "_scroll_area"):
+                            _layout: QBoxLayout = self._widget._qwidget.layout()
+                        else:
+                            _layout = self.native.layout()
                         if _layout.menuBar() is None:
                             _layout.setMenuBar(widget.native)
                         else:
@@ -185,6 +190,8 @@ class ClassGuiBase(BaseGui):
                         try:
                             widget = self._create_widget_from_method(widget)
                         except Exception:
+                            msg = f"Could not convert {widget!r} into a widget."
+                            warnings.warn(msg, UserWarning)
                             continue
                     
                     elif hasattr(widget, "__magicclass_parent__") or \
@@ -237,7 +244,9 @@ class ClassGuiBase(BaseGui):
         self._unify_label_widths()
         return None
 
-def make_gui(container: type[ContainerWidget], no_margin: bool = True):
+_C = TypeVar("_C", bound=ContainerWidget)
+
+def make_gui(container: type[_C], no_margin: bool = True) -> type[_C | ClassGuiBase]:
     """
     Make a ClassGui class from a Container widget.
     Because GUI class inherits Container here, functions that need overriden must be defined
@@ -358,6 +367,7 @@ def make_gui(container: type[ContainerWidget], no_margin: bool = True):
                 if hasattr(widget, "reset_choices"):
                     widget.reset_choices()
         
+        
         def close(self: cls):
             current_self = self._search_parent_magicclass()
             
