@@ -1,8 +1,7 @@
 from __future__ import annotations
-from typing import Callable, Iterable, Any
+from typing import Callable, Iterable, Any, Generic, TypeVar
 import re
-from PyQt5.QtWidgets import QMenu
-from qtpy.QtWidgets import QPushButton, QAction, QWidgetAction, QToolButton, QWidget
+from qtpy.QtWidgets import QPushButton, QAction, QWidgetAction, QToolButton, QWidget, QMenu
 from qtpy.QtGui import QIcon
 from qtpy.QtCore import QSize
 from magicgui.events import Signal
@@ -32,14 +31,14 @@ class FunctionGuiPlus(FunctionGui):
                     f"{e} in call to '{self._callable_name}{sig}'.\n"
                     "To avoid this error, you can bind a value or callback to the "
                     f"parameter:\n\n    {self._callable_name}.{missing}.bind(value)"
-                    "\n\nOr use the 'bind' option in the magicgui decorator:\n\n"
-                    f"    @magicgui({missing}={{'bind': value}})\n"
+                    "\n\nOr use the 'bind' option in the set_option decorator:\n\n"
+                    f"    @set_option({missing}={{'bind': value}})\n"
                     f"    def {self._callable_name}{sig}: ..."
                 )
                 raise TypeError(msg) from None
             else:
                 raise
-
+                    
         bound.apply_defaults()
         
         # 1. Parameter recording
@@ -72,7 +71,8 @@ class FunctionGuiPlus(FunctionGui):
                 callback(self, value, return_type)
         self.called.emit(value)
         return value
-    
+
+
     def insert(self, key: int, widget: Widget):
         """Insert widget at ``key``."""
         if isinstance(widget, (ValueWidget, ContainerWidget)):
@@ -135,8 +135,9 @@ class PushButtonPlus(PushButton):
         return self._icon_path
     
     @icon_path.setter
-    def icon_path(self, path:str):
-        icon = QIcon(str(path))
+    def icon_path(self, path):
+        path = str(path)
+        icon = QIcon(path)
         self.native.setIcon(icon)
     
     @property
@@ -343,11 +344,10 @@ class Action(AbstractAction):
         return self._icon_path
     
     @icon_path.setter
-    def icon_path(self, path: str):
+    def icon_path(self, path):
         path = str(path)
         icon = QIcon(path)
         self.native.setIcon(icon)
-        self._icon_path = path
     
     def from_options(self, options: dict[str] | Callable):
         if callable(options):
@@ -361,9 +361,11 @@ class Action(AbstractAction):
                 setattr(self, k, v)
         return None
 
-class WidgetAction(AbstractAction):
-    
-    def __init__(self, widget: Widget, label: str = None, parent=None):
+_W = TypeVar("_W", bound=Widget)
+
+
+class WidgetAction(AbstractAction, Generic[_W]):
+    def __init__(self, widget: _W, label: str = None, parent=None):
         if not isinstance(widget, (Widget, mguiLike)):
             raise TypeError(f"The first argument must be a magicgui-like widget, got {type(widget)}")
         
@@ -410,7 +412,8 @@ class WidgetAction(AbstractAction):
     @text.setter
     def text(self, value: str):
         self.native.setText(value)
-    
+
+
     def _labeled_widget(self):
         return self.widget._labeled_widget()
     
@@ -418,9 +421,11 @@ class WidgetAction(AbstractAction):
     def render(self):
         return self.widget.render()
 
+
     def _repr_png_(self):
         return self.widget._repr_png_()
-    
+
+
 class _LabeledWidgetAction(WidgetAction):
     widget: _LabeledWidget
     
