@@ -183,13 +183,13 @@ class ToolBarGui(ContainerLikeGui):
     
     def _fast_insert(self, key: int, obj: AbstractAction | Callable) -> None:
         """
-        Insert object into the menu. Could be widget or callable.
+        Insert object into the toolbar. Could be widget or callable.
 
         Parameters
         ----------
         key : int
             Position to insert.
-        obj : Callable | MenuGuiBase | AbstractAction | Widget
+        obj : Callable or AbstractAction
             Object to insert.
         """
         if isinstance(obj, Callable):
@@ -215,7 +215,7 @@ class ToolBarGui(ContainerLikeGui):
                 _hide_labels = (_LabeledWidgetAction, ButtonWidget, FreeWidget, Label, 
                                 FunctionGui, Image, Table)
                 _obj = obj
-                if not isinstance(obj.widget, _hide_labels):
+                if (not isinstance(obj.widget, _hide_labels)) and self.labels:
                     _obj = _LabeledWidgetAction.from_action(obj)
                 _obj.parent = self
                 insert_action_like(self.native, key, _obj.native)
