@@ -146,7 +146,7 @@ class _ScrollableContainer(ContainerBase):
         self._inner_widget.setLayout(self._layout)
         self._scroll_area.setWidget(self._inner_widget)
         
-        self._qwidget.setLayout(QtW.QHBoxLayout())
+        self._qwidget.setLayout(QtW.QVBoxLayout())
         self._qwidget.layout().addWidget(self._scroll_area)
         self._qwidget.layout().setContentsMargins(0, 0, 0, 0)
 
@@ -171,7 +171,7 @@ class _DraggableContainer(ContainerBase):
         self._inner_widget.setLayout(self._layout)
         self._scroll_area.setWidget(self._inner_widget)
         
-        self._qwidget.setLayout(QtW.QHBoxLayout())
+        self._qwidget.setLayout(QtW.QVBoxLayout())
         self._qwidget.layout().addWidget(self._scroll_area)
         self._qwidget.layout().setContentsMargins(0, 0, 0, 0)
         QtW.QScroller.grabGesture(self._scroll_area, QtW.QScroller.LeftMouseButtonGesture)
@@ -434,6 +434,15 @@ class CollapsibleContainer(ContainerWidget):
     @btn_text.setter
     def btn_text(self, text: str):
         self._widget._expand_btn.setText(text)
+    
+    @property
+    def collapsed(self) -> bool:
+        return self._widget.collapsed
+    
+    @collapsed.setter
+    def collapsed(self, value: bool):
+        self._widget._expand_btn.setChecked(value)
+
 
 @wrap_container(base=_HCollapsibleContainer)
 class HCollapsibleContainer(ContainerWidget):
@@ -446,6 +455,14 @@ class HCollapsibleContainer(ContainerWidget):
     @btn_text.setter
     def btn_text(self, text: str):
         self._widget._expand_btn.setText(text)
+        
+    @property
+    def collapsed(self) -> bool:
+        return self._widget.collapsed
+    
+    @collapsed.setter
+    def collapsed(self, value: bool):
+        self._widget._expand_btn.setChecked(value)
 
 
 @wrap_container(base=_ListContainer)
