@@ -14,21 +14,44 @@ Args = TypeVar("Args")
 Returns = TypeVar("Returns")
 T = TypeVar("T")
 
-def set_options(**options):
+
+def set_options(layout: str = "vertical", 
+                call_button: bool | str | None = None,
+                auto_call: bool = False,
+                **options) -> Callable[[Callable[[Args], Returns]], Callable[[Args], Returns]]:
     """
-    Set MagicSignature to functions. By decorating a function like below:
+    Set MagicSignature to functions. 
     
-    >>> @set_options(x={"value": -1})
-    >>> def func(x):
-    >>>     ...
+    By decorating a method with this function, ``magicgui`` will create a widget with these
+    options.
     
-    then magicgui knows what widget it should be converted to. 
+    Parameters
+    ----------
+    layout : str, optional
+        The type of layout to use. Must be one of {'horizontal', 'vertical'}.
+        by default "vertical".
+    call_button : bool or str, optional
+        If ``True``, create an additional button that calls the original
+        function when clicked.  If a ``str``, set the button text. If None (the
+        default), it defaults to True when ``auto_call`` is False, and False
+        otherwise.
+    auto_call : bool, optional
+        If ``True``, changing any parameter in either the GUI or the widget attributes
+        will call the original function with the current settings. by default False
+    options : dict
+        Parameter options.
     """    
     def wrapper(func: Callable[[Args], Returns]) -> Callable[[Args], Returns]:
-        upgrade_signature(func, gui_options=options)
+        upgrade_signature(func, 
+                          gui_options=options,
+                          additional_options={"call_button": call_button,
+                                              "layout": layout,
+                                              "auto_call": auto_call}
+                          )
         return func
     return wrapper
 
+
 def set_design(width: int = None, height: int = None, min_width: int = None, min_height: int = None,
                max_width: int = None, max_height: int = None, text: str = None, 
                icon_path: str = None, icon_size: tuple [ int,int]=None,
@@ -91,6 +114,7 @@ def set_design(width: int = None, height: int = None, min_width: int = None, min
     
     return wrapper
 
+
 def click(enables: nStrings = None, disables: nStrings = None, enabled: bool = True,
           shows: nStrings = None, hides: nStrings = None, visible: bool = True):
     """
@@ -136,13 +160,13 @@ def click(enables: nStrings = None, disables: nStrings = None, enabled: bool = T
         return f
     return wrapper
 
+
 def do_not_record(method: Callable[[Args], Returns]) -> Callable[[Args], Returns]:
-    """
-    Wrapped method will not be recorded in macro.
-    """    
+    """Wrapped method will not be recorded in macro."""    
     upgrade_signature(method, additional_options={"record": False})
     return method
 
+
 def bind_key(*key) -> Callable[[Callable[[Args], Returns]], Callable[[Args], Returns]]:
     """
     Define a keybinding to a button or an action.
@@ -161,6 +185,7 @@ def bind_key(*key) -> Callable[[Callable[[Args], Returns]], Callable[[Args], Ret
         return method
     return wrapper
 
+
 def _assert_iterable(obj):
     if obj is None:
         obj = []
@@ -168,6 +193,7 @@ def _assert_iterable(obj):
         obj = [obj]
     return obj
 
+
 def _iter_widgets(self: BaseGui, 
                   descriptors: Iterable[list[str]] | Iterable[Callable]
                   ) -> Iterator[ButtonWidget|Action]:
